@@ -165,7 +165,8 @@ class PrecisionPlugin(CheckpointHooks):
     def _track_grad_norm(self, trainer: "pl.Trainer") -> None:
         if trainer.track_grad_norm == -1:
             return
-        grad_norm_dict = grad_norm(trainer.lightning_module, trainer.track_grad_norm, trainer.logger.group_separator)
+        kwargs = {"group_separator": trainer.logger.group_separator} if trainer.logger is not None else {}
+        grad_norm_dict = grad_norm(trainer.lightning_module, trainer.track_grad_norm, **kwargs)
         if grad_norm_dict:
             prev_fx = trainer.lightning_module._current_fx_name
             trainer.lightning_module._current_fx_name = "on_before_optimizer_step"
