@@ -15,6 +15,7 @@ from typing import Any, Optional, Union
 
 import torch
 
+from pytorch_lightning.plugins.io.checkpoint_plugin import CheckpointIO
 from pytorch_lightning.plugins.training_type.training_type_plugin import TrainingTypePlugin
 from pytorch_lightning.utilities import _XLA_AVAILABLE
 
@@ -22,8 +23,12 @@ from pytorch_lightning.utilities import _XLA_AVAILABLE
 class SingleDevicePlugin(TrainingTypePlugin):
     """Plugin that handles communication on a single device."""
 
-    def __init__(self, device: torch.device):
-        super().__init__()
+    def __init__(
+        self,
+        device: torch.device,
+        checkpoint_io: Optional[CheckpointIO] = None,
+    ):
+        super().__init__(checkpoint_io)
         self.device: torch.device = device
         self.global_rank = 0
         self.local_rank = 0
@@ -38,9 +43,8 @@ class SingleDevicePlugin(TrainingTypePlugin):
         return self.root_device.type == "cuda" and torch.cuda.is_available()
 
     def reduce(self, tensor: Union[Any, torch.Tensor], *args: Any, **kwargs: Any) -> Union[Any, torch.Tensor]:
-        """
-        Reduces a tensor from several distributed processes to one aggregated tensor.
-        As this plugin only operates with a single device, the reduction is simply the identity.
+        """Reduces a tensor from several distributed processes to one aggregated tensor. As this plugin only
+        operates with a single device, the reduction is simply the identity.
 
         Args:
             tensor: the tensor to sync and reduce
@@ -53,7 +57,7 @@ class SingleDevicePlugin(TrainingTypePlugin):
         return tensor
 
     def all_gather(self, tensor: torch.Tensor, group: Optional[Any] = None, sync_grads: bool = False) -> torch.Tensor:
-        """Perform a all_gather on all processes"""
+        """Perform a all_gather on all processes."""
         return tensor
 
     @property
@@ -63,9 +67,8 @@ class SingleDevicePlugin(TrainingTypePlugin):
     def model_to_device(self) -> None:
         self._model.to(self.root_device)
 
-    def setup(self, model: torch.nn.Module) -> torch.nn.Module:
+    def setup(self) -> None:
         self.model_to_device()
-        return self.model
 
     @property
     def is_global_zero(self) -> bool:
