@@ -177,7 +177,7 @@ class TrainerDataLoadingMixin(ABC):
         if self._requires_distributed_sampler(dataloader):
             if not isinstance(dataloader.sampler, (SequentialSampler, RandomSampler)):
                 raise MisconfigurationException(
-                    "You seem to have configured a sampler in your DataLoader. This will be replaced "
+                    "You seem to have configured a sampler in your DataLoader. This will be replaced"
                     " by `DistributedSampler` since `replace_sampler_ddp` is True and you are using"
                     " distributed training. Either remove the sampler from your DataLoader or set"
                     " `replace_sampler_ddp=False` if you want to use your custom sampler."
@@ -455,9 +455,11 @@ class TrainerDataLoadingMixin(ABC):
                         loader, SequentialSampler(loader.dataset), mode=mode
                     )
                 else:
-                    rank_zero_warn(
-                        f"Your `{mode.dataloader_prefix}_dataloader` has `shuffle=True`,"
-                        "it is strongly recommended that you turn this off for val/test/predict dataloaders."
+                    apply_to_collection(
+                        loader.loaders if isinstance(loader, CombinedLoader) else loader,
+                        DataLoader,
+                        self._check_eval_shuffling,
+                        mode=mode,
                     )
 
         if any(dl is None for dl in dataloaders):
@@ -478,7 +480,7 @@ class TrainerDataLoadingMixin(ABC):
         module = model or self.lightning_module or self.datamodule
         if len(dataloaders) != 0:
             for i, dataloader in enumerate(dataloaders):
-                num_batches = (
+                orig_num_batches = num_batches = (
                     len(dataloader)
                     if has_len_all_ranks(dataloader, self.training_type_plugin, module)
                     else float("inf")
@@ -504,7 +506,7 @@ class TrainerDataLoadingMixin(ABC):
                     min_pct = 1.0 / len(dataloader)
                     raise MisconfigurationException(
                         f"you requested to check {limit_eval_batches} of the `{mode.dataloader_prefix}_dataloader` but"
-                        f" {limit_eval_batches}*{num_batches} < 1. Please increase the"
+                        f" {limit_eval_batches} * {orig_num_batches} < 1. Please increase the"
                         f" `limit_{mode.dataloader_prefix}_batches` flag. Try at least"
                         f" `limit_{mode.dataloader_prefix}_batches={min_pct}`"
                     )
@@ -620,3 +622,16 @@ class TrainerDataLoadingMixin(ABC):
             dataloader = apply_to_collection(dataloader, DataLoader, replace_sampler)
 
         return dataloader
+
+    @staticmethod
+    def _check_eval_shuffling(dataloader, mode):
+        if (
+            hasattr(dataloader, "sampler")
+            and not isinstance(dataloader.sampler, SequentialSampler)
+            and not isinstance(dataloader.dataset, IterableDataset)
+        ):
+            rank_zero_warn(
+                f"Your `{mode.dataloader_prefix}_dataloader` has `shuffle=True`,"
+                " it is strongly recommended that you turn this off for val/test/predict dataloaders.",
+                category=UserWarning,
+            )
