@@ -45,8 +45,7 @@ class TrainerFn(LightningEnum):
 
     @property
     def _setup_fn(self) -> "TrainerFn":
-        """
-        ``FITTING`` is used instead of ``TUNING`` as there are no "tune" dataloaders.
+        """``FITTING`` is used instead of ``TUNING`` as there are no "tune" dataloaders.
 
         This is used for the ``setup()`` and ``teardown()`` hooks
         """
@@ -54,8 +53,7 @@ class TrainerFn(LightningEnum):
 
 
 class RunningStage(LightningEnum):
-    """
-    Enum for the current running stage.
+    """Enum for the current running stage.
 
     This stage complements :class:`TrainerFn` by specifying the current running stage for each function.
     More than one running stage value can be set while a :class:`TrainerFn` is running:
@@ -78,10 +76,18 @@ class RunningStage(LightningEnum):
     def evaluating(self) -> bool:
         return self in (self.VALIDATING, self.TESTING)
 
+    @property
+    def dataloader_prefix(self) -> Optional[str]:
+        if self in (self.SANITY_CHECKING, self.TUNING):
+            return None
+        if self == self.VALIDATING:
+            return "val"
+        return self.value
+
 
 @dataclass
 class TrainerState:
-    """Dataclass to encapsulate the current :class:`~pytorch_lightning.trainer.trainer.Trainer` state"""
+    """Dataclass to encapsulate the current :class:`~pytorch_lightning.trainer.trainer.Trainer` state."""
 
     status: TrainerStatus = TrainerStatus.INITIALIZING
     fn: Optional[TrainerFn] = None
